@@ -44,6 +44,9 @@ def setPathPermissions(path, mode):
 
     abs_path = os.path.abspath(path)
 
+    # convert from octal to decimal
+    mode = int(str(mode), 8)
+
     if os.path.exists(abs_path):
         try:
             # if is a directory, set permissions recursively
