@@ -5,6 +5,7 @@ import logging
 from logging.handlers import RotatingFileHandler
 import os
 import __builtin__
+import macman
 
 
 log_path = '/usr/local/techops/logs/'
@@ -24,6 +25,9 @@ def setupLogging(log_file=None):
         if not os.path.exists(log_path):
             os.makedirs(log_path)
 
+        # set file permissions so non-root users can write to logs
+        macman.files.setPathPermissions(log_path, 0777)
+
         # setup log rotation
         handler = RotatingFileHandler('%s%s' % (log_path, log_file), mode='a', maxBytes=5 * 1024 * 1024, backupCount=1,
                                       encoding=None, delay=0)
@@ -48,3 +52,4 @@ def writeLog(log_string=None):
     if log and log_string:
         log_string = '\t'.join(log_string.strip().splitlines(True))
         log.info(log_string)
+
