@@ -4,6 +4,15 @@
 
 from subprocess import Popen, PIPE
 import macman
+import os
+import sys
+
+
+def checkIfRoot():
+    if not os.geteuid() == 0:
+        return False
+    else:
+        return True
 
 
 def tildeToPath(username, path):
@@ -163,11 +172,11 @@ def defaults(*args):
     """
 
     """
-
-    defaults_args = ["/usr/bin/defaults"]
+    defaults_args = ['/usr/bin/defaults']
     defaults_args.extend(args)
 
-    p = Popen(defaults_args, stdout=PIPE, stderr=PIPE, shell=True)
+    p = Popen(defaults_args, stdout=PIPE, stderr=PIPE)
     output, err = p.communicate()
 
-    return output
\ No newline at end of file
+    return output
+
