@@ -24,7 +24,7 @@ def getTimezone():
 def setTimezone(timezone):
     """ Set timezone """
 
-    macman.logs.writeLog('Setting time zone to "%S"' % timezone)
+    macman.logs.writeLog('Setting time zone to "%s"' % timezone)
     macman.misc.systemsetup('-settimezone', "%s" % timezone)
 
 
